package com.ruoyi.web.controller.school;

import java.util.List;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.ResponseBody;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.TbSchoolMajorQsRecord;
import com.ruoyi.system.service.ITbSchoolMajorQsRecordService;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 学校专业QSController
 * 
 * @author ruoyi
 * @date 2022-11-16
 */
@Controller
@RequestMapping("/system/record")
public class TbSchoolMajorQsRecordController extends BaseController
{
    private String prefix = "system/record";

    @Autowired
    private ITbSchoolMajorQsRecordService tbSchoolMajorQsRecordService;

    @RequiresPermissions("system:record:view")
    @GetMapping()
    public String record()
    {
        return prefix + "/record";
    }

    /**
     * 查询学校专业QS列表
     */
    @RequiresPermissions("system:record:list")
    @PostMapping("/list")
    @ResponseBody
    public TableDataInfo list(TbSchoolMajorQsRecord tbSchoolMajorQsRecord)
    {
        startPage();
        List<TbSchoolMajorQsRecord> list = tbSchoolMajorQsRecordService.selectTbSchoolMajorQsRecordList(tbSchoolMajorQsRecord);
        return getDataTable(list);
    }

    /**
     * 导出学校专业QS列表
     */
    @RequiresPermissions("system:record:export")
    @Log(title = "学校专业QS", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    @ResponseBody
    public AjaxResult export(TbSchoolMajorQsRecord tbSchoolMajorQsRecord)
    {
        List<TbSchoolMajorQsRecord> list = tbSchoolMajorQsRecordService.selectTbSchoolMajorQsRecordList(tbSchoolMajorQsRecord);
        ExcelUtil<TbSchoolMajorQsRecord> util = new ExcelUtil<TbSchoolMajorQsRecord>(TbSchoolMajorQsRecord.class);
        return util.exportExcel(list, "学校专业QS数据");
    }

    /**
     * 新增学校专业QS
     */
    @GetMapping("/add")
    public String add()
    {
        return prefix + "/add";
    }

    /**
     * 新增保存学校专业QS
     */
    @RequiresPermissions("system:record:add")
    @Log(title = "学校专业QS", businessType = BusinessType.INSERT)
    @PostMapping("/add")
    @ResponseBody
    public AjaxResult addSave(TbSchoolMajorQsRecord tbSchoolMajorQsRecord)
    {
        return toAjax(tbSchoolMajorQsRecordService.insertTbSchoolMajorQsRecord(tbSchoolMajorQsRecord));
    }

    /**
     * 修改学校专业QS
     */
    @RequiresPermissions("system:record:edit")
    @GetMapping("/edit/{id}")
    public String edit(@PathVariable("id") Long id, ModelMap mmap)
    {
        TbSchoolMajorQsRecord tbSchoolMajorQsRecord = tbSchoolMajorQsRecordService.selectTbSchoolMajorQsRecordById(id);
        mmap.put("tbSchoolMajorQsRecord", tbSchoolMajorQsRecord);
        return prefix + "/edit";
    }

    /**
     * 修改保存学校专业QS
     */
    @RequiresPermissions("system:record:edit")
    @Log(title = "学校专业QS", businessType = BusinessType.UPDATE)
    @PostMapping("/edit")
    @ResponseBody
    public AjaxResult editSave(TbSchoolMajorQsRecord tbSchoolMajorQsRecord)
    {
        return toAjax(tbSchoolMajorQsRecordService.updateTbSchoolMajorQsRecord(tbSchoolMajorQsRecord));
    }

    /**
     * 删除学校专业QS
     */
    @RequiresPermissions("system:record:remove")
    @Log(title = "学校专业QS", businessType = BusinessType.DELETE)
    @PostMapping( "/remove")
    @ResponseBody
    public AjaxResult remove(String ids)
    {
        return toAjax(tbSchoolMajorQsRecordService.deleteTbSchoolMajorQsRecordByIds(ids));
    }
}
